@@ -1,53 +1,54 @@
 #! /usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 a remote python shell
 
 for injection into startserver.py
 """
+
 import os
 import select
 import socket
 import sys
 from threading import Thread
 from traceback import print_exc
+from typing import NoReturn
 
 
-def clientside():
+def clientside() -> NoReturn:
     print("client side starting")
-    host, port = sys.argv[1].split(":")
-    port = int(port)
-    myself = open(os.path.abspath(sys.argv[0]), "rU").read()
+    host, portstr = sys.argv[1].split(":")
+    port = int(portstr)
+    myself = open(os.path.abspath(sys.argv[0])).read()
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     sock.connect((host, port))
-    sock.sendall(repr(myself) + "\n")
+    sock.sendall((repr(myself) + "\n").encode())
     print("send boot string")
     inputlist = [sock, sys.stdin]
     try:
         while 1:
             r, w, e = select.select(inputlist, [], [])
             if sys.stdin in r:
-                line = raw_input()
-                sock.sendall(line + "\n")
+                line = input()
+                sock.sendall((line + "\n").encode())
             if sock in r:
-                line = sock.recv(4096)
+                line = sock.recv(4096).decode()
                 sys.stdout.write(line)
                 sys.stdout.flush()
-    except:
+    except BaseException:
         import traceback
 
-        print(traceback.print_exc())
+        traceback.print_exc()
 
     sys.exit(1)
 
 
 class promptagent(Thread):
-    def __init__(self, clientsock):
+    def __init__(self, clientsock) -> None:
         print("server side starting")
-        Thread.__init__(self)
+        super.__init__()  # type: ignore[call-overload]
         self.clientsock = clientsock
 
-    def run(self):
+    def run(self) -> None:
         print("Entering thread prompt loop")
         clientfile = self.clientsock.makefile("w")
 
@@ -56,7 +57,7 @@ class promptagent(Thread):
 
         while 1:
             try:
-                clientfile.write("%s %s >>> " % loc)
+                clientfile.write("{} {} >>> ".format(*loc))
                 clientfile.flush()
                 line = filein.readline()
                 if not line:
@@ -67,7 +68,7 @@ class promptagent(Thread):
                     try:
                         try:
                             exec(compile(line + "\n", "<remote pyin>", "single"))
-                        except:
+                        except BaseException:
                             print_exc()
                     finally:
                         sys.stdout = oldout
